# Auth-Firebase

A simple Python wrapper for making use of the Firebase API.

Firebase offers unlimited free authentication with email and password. This package is designed to be used with any web framework. The example provided is with Flask.

# Install

    pip install Auth-Firebase
